--- kernel-5-16-13/tas2764.h	2022-03-09 13:22:14.414694800 +0800
+++ kernel-5-16-13-modified/tas27xx.h	2022-03-11 14:07:20.073656800 +0800
@@ -1,24 +1,32 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 /*
- * tas2764.h - ALSA SoC Texas Instruments TAS2764 Mono Audio Amplifier
+ * tas2764.h - ALSA SoC Texas Instruments TAS2764/TAS2780 Mono Audio Amplifier
  *
- * Copyright (C) 2020 Texas Instruments Incorporated -  https://www.ti.com
+ * Copyright (C) 2022 Texas Instruments Incorporated -  https://www.ti.com
  *
- * Author: Dan Murphy <dmurphy@ti.com>
+ * Author:Raphael Xu
  */
 
-#ifndef __TAS2764__
-#define __TAS2764__
+#ifndef __TAS27XX__
+#define __TAS27XX__
 
 /* Book Control Register */
-#define TAS2764_BOOKCTL_PAGE	0
-#define TAS2764_BOOKCTL_REG	127
+#define TAS27XX_BOOKCTL_PAGE	0
+#define TAS27XX_BOOKCTL_REG	127
 #define TAS2764_REG(page, reg)	((page * 128) + reg)
 
 /* Page */
 #define TAS2764_PAGE		TAS2764_REG(0X0, 0x00)
 #define TAS2764_PAGE_PAGE_MASK	255
 
+#define TAS27XX_REG(book, page, reg)  (((book * 256 * 128) + \
+					(page * 128)) + reg)
+#define TAS27XX_P253_REG_D 		TAS27XX_REG(0x0, 0xfd, 0xd)
+#define TAS27XX_SPECIAL_ID		TAS27XX_REG(0x0, 0xfd, 0x7c)
+#define TAS27XX_BOOK_ID(reg)	(reg / (256 * 128))
+#define TAS27XX_PAGE_ID(reg)	((reg % (256 * 128)) / 128)
+#define TAS27XX_PAGE_REG(reg)	((reg % (256 * 128)) % 128)
+
 /* Software Reset */
 #define TAS2764_SW_RST	TAS2764_REG(0X0, 0x01)
 #define TAS2764_RST	BIT(0)
@@ -77,6 +85,10 @@
 #define TAS2764_TDM_CFG3_RXS_SHIFT	0x4
 #define TAS2764_TDM_CFG3_MASK		GENMASK(3, 0)
 
+/* TDM Configuration Reg4 */
+#define TAS2764_TDM_CFG4		TAS2764_REG(0X0, 0x0d)
+#define TAS2764_TDM_CFG4_TX_OFFSET_MASK	GENMASK(3, 1)
+
 /* TDM Configuration Reg5 */
 #define TAS2764_TDM_CFG5		TAS2764_REG(0X0, 0x0e)
 #define TAS2764_TDM_CFG5_VSNS_MASK	BIT(6)
@@ -89,4 +101,14 @@
 #define TAS2764_TDM_CFG6_ISNS_ENABLE	BIT(6)
 #define TAS2764_TDM_CFG6_50_MASK	GENMASK(5, 0)
 
-#endif /* __TAS2764__ */
+/* INT&CLK CFG */
+#define TAS27XX_CLK_CFG			TAS2764_REG(0X0, 0x5c)
+#define TAS27XX_CLK_CFG_MASK		GENMASK(7, 6)
+#define TAS27XX_CLK_CFG_ENABLE		(BIT(7) | BIT(6))
+
+typedef enum tas27xx {
+	TAS2764 = 0,
+	TAS2780 = 1,
+} tas27xx_t;
+
+#endif /* __TAS27XX__ */
